pub fn render_errors( errors: &[CompileError], source: &str, filename: &str, ) -> String
Render a list of compile errors to a string (for tests) using the given filename as the diagnostic source label.