short_line

Function short_line 

pub fn short_line(filename: &str, source: &str, err: &CompileError) -> String
One terse path:line:col: severity[category]: message line for a single error against its source. The front-end’s project-failure short renderer flattens an attributed error to (label, text, error) and calls this.